[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Xen-changelog] [xen-unstable] xend: Enlarge the memory balloon size for domain creation since shadow



# HG changeset patch
# User Keir Fraser <keir.fraser@xxxxxxxxxx>
# Date 1265792868 0
# Node ID d28a351f05898ce6f81f0b3a2dbbb383203cc218
# Parent  6dd69b92d13149dd78603d0cfc8395c3ededd81b
xend: Enlarge the memory balloon size for domain creation since shadow
pre-allocation size has changed from 1M to 4M.

Signed-off-by: Dongxiao Xu <dongxiao.xu@xxxxxxxxx>
---
 tools/python/xen/xend/XendDomainInfo.py |    5 ++---
 1 files changed, 2 insertions(+), 3 deletions(-)

diff -r 6dd69b92d131 -r d28a351f0589 tools/python/xen/xend/XendDomainInfo.py
--- a/tools/python/xen/xend/XendDomainInfo.py   Wed Feb 10 09:06:59 2010 +0000
+++ b/tools/python/xen/xend/XendDomainInfo.py   Wed Feb 10 09:07:48 2010 +0000
@@ -2519,9 +2519,8 @@ class XendDomainInfo:
         # There is an implicit memory overhead for any domain creation. This
         # overhead is greater for some types of domain than others. For
         # example, an x86 HVM domain will have a default shadow-pagetable
-        # allocation of 1MB. We free up 4MB here to be on the safe side.
-        # 2MB memory allocation was not enough in some cases, so it's 4MB now
-        balloon.free(4*1024, self) # 4MB should be plenty
+        # allocation of 4MB. We free up 16MB here to be on the safe side.
+        balloon.free(16*1024, self) # 16MB should be plenty
 
         ssidref = 0
         if security.on() == xsconstants.XS_POLICY_USE:

_______________________________________________
Xen-changelog mailing list
Xen-changelog@xxxxxxxxxxxxxxxxxxx
http://lists.xensource.com/xen-changelog


 


Rackspace

Lists.xenproject.org is hosted with RackSpace, monitoring our
servers 24x7x365 and backed by RackSpace's Fanatical Support®.